==> payara-embedded-all-5.2020.4-sources.jar: org/glassfish/enterprise/iiop/api/ORBLazyServiceInitializer.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.enterprise.iiop.api;

import org.glassfish.internal.grizzly.LazyServiceInitializer;

import org.jvnet.hk2.annotations.Service;
import javax.inject.Inject;
import javax.inject.Named;

import org.glassfish.hk2.api.PostConstruct;

import org.omg.CORBA.ORB;

import javax.naming.NamingException;
import java.nio.channels.SelectableChannel;
import java.util.logging.Level;
import com.sun.logging.LogDomains;
import java.util.logging.Logger;



/**
 *
 * @author Ken Saks
 */
@Service
@Named("iiop-service")
public class ORBLazyServiceInitializer implements LazyServiceInitializer, PostConstruct {

static Logger logger = LogDomains.getLogger(ORBLazyServiceInitializer.class, LogDomains.SERVER_LOGGER);


    @Inject
    private GlassFishORBHelper orbHelper;

    boolean initializedSuccessfully = false;

    public void postConstruct() {
    }

    public String getServiceName() {
       
        return "iiop-service";
    }


    public boolean initializeService() {

        try {

            orbHelper.getORB();

            initializedSuccessfully = true;

            // TODO add check to ensure that lazy init is enabled for the orb
            // and throw exception if not

        } catch(Exception e) {
            logger.log(Level.WARNING, "ORB initialization failed in lazy init", e);
        }

        return initializedSuccessfully;
    }


    public void handleRequest(SelectableChannel channel) {
        if( initializedSuccessfully) {
            orbHelper.getSelectableChannelDelegate().handleRequest(channel);
        } else {
            logger.log(Level.WARNING, "Cannot handle SelectableChannel request in ORBLazyServiceInitializer." +
                    "ORB did not initialize successfully");
        }
    }




}

==> payara-embedded-all-6.2023.4-sources.jar: org/glassfish/enterprise/iiop/api/ORBLazyServiceInitializer.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.enterprise.iiop.api;

import org.glassfish.internal.grizzly.LazyServiceInitializer;

import org.jvnet.hk2.annotations.Service;
import jakarta.inject.Inject;
import jakarta.inject.Named;

import org.glassfish.hk2.api.PostConstruct;

import org.omg.CORBA.ORB;

import javax.naming.NamingException;
import java.nio.channels.SelectableChannel;
import java.util.logging.Level;
import com.sun.logging.LogDomains;
import java.util.logging.Logger;



/**
 *
 * @author Ken Saks
 */
@Service
@Named("iiop-service")
public class ORBLazyServiceInitializer implements LazyServiceInitializer, PostConstruct {

static Logger logger = LogDomains.getLogger(ORBLazyServiceInitializer.class, LogDomains.SERVER_LOGGER);


    @Inject
    private GlassFishORBHelper orbHelper;

    boolean initializedSuccessfully = false;

    public void postConstruct() {
    }

    public String getServiceName() {
       
        return "iiop-service";
    }


    public boolean initializeService() {

        try {

            orbHelper.getORB();

            initializedSuccessfully = true;

            // TODO add check to ensure that lazy init is enabled for the orb
            // and throw exception if not

        } catch(Exception e) {
            logger.log(Level.WARNING, "ORB initialization failed in lazy init", e);
        }

        return initializedSuccessfully;
    }


    public void handleRequest(SelectableChannel channel) {
        if( initializedSuccessfully) {
            orbHelper.getSelectableChannelDelegate().handleRequest(channel);
        } else {
            logger.log(Level.WARNING, "Cannot handle SelectableChannel request in ORBLazyServiceInitializer." +
                    "ORB did not initialize successfully");
        }
    }




}
